pub unsafe extern "C" fn NK_set_unencrypted_read_write_admin(
admin_pin: *const c_char,
) -> c_intExpand description
Make unencrypted volume read-write. Device hides unencrypted volume for a second therefore make sure buffers are flushed before running. Does nothing if firmware version is not matched Firmware range: Storage v0.49, v0.51+ Storage only @param admin_pin 20 characters Admin PIN @return command processing error code