#[repr(C)]pub struct NK_SD_usage_data {
pub write_level_min: u8,
pub write_level_max: u8,
}Expand description
Data about the usage of the SD card.
Fields
write_level_min: u8The minimum write level, as a percentage of the total card size.
write_level_max: u8The maximum write level, as a percentage of the total card size.