#[repr(C)]pub struct NK_device_info {
pub model: NK_device_model,
pub path: *mut c_char,
pub serial_number: *mut c_char,
pub next: *mut NK_device_info,
}Expand description
The connection info for a Nitrokey device as a linked list.
Fields
model: NK_device_modelThe model of the Nitrokey device.
path: *mut c_charThe USB device path for NK_connect_with_path.
serial_number: *mut c_charThe serial number.
next: *mut NK_device_infoThe pointer to the next element of the linked list or null if this is the last element in the list.