NK_status

Struct NK_status 

#[repr(C)]
pub struct NK_status { pub firmware_version_major: u8, pub firmware_version_minor: u8, pub serial_number_smart_card: u32, pub config_numlock: u8, pub config_capslock: u8, pub config_scrolllock: u8, pub otp_user_password: bool, }
Stores the common device status for all Nitrokey devices.

Fields

firmware_version_major: u8

The major firmware version, e. g. 0 in v0.40.

firmware_version_minor: u8

The minor firmware version, e. g. 40 in v0.40.

serial_number_smart_card: u32

The serial number of the smart card.

config_numlock: u8

The HOTP slot to generate a password from if the numlock key is pressed twice (slot 0-1, or any other value to disable the function).

config_capslock: u8

The HOTP slot to generate a password from if the capslock key is pressed twice (slot 0-1, or any other value to disable the function).

config_scrolllock: u8

The HOTP slot to generate a password from if the scrolllock key is pressed twice (slot 0-1, or any other value to disable the function).

otp_user_password: bool

Indicates whether the user password is required to generate an OTP value.