NK_storage_status

Struct NK_storage_status 

#[repr(C)]
pub struct NK_storage_status {
Show 16 fields pub unencrypted_volume_read_only: bool, pub unencrypted_volume_active: bool, pub encrypted_volume_read_only: bool, pub encrypted_volume_active: bool, pub hidden_volume_read_only: bool, pub hidden_volume_active: bool, pub firmware_version_major: u8, pub firmware_version_minor: u8, pub firmware_locked: bool, pub serial_number_sd_card: u32, pub serial_number_smart_card: u32, pub user_retry_count: u8, pub admin_retry_count: u8, pub new_sd_card_found: bool, pub filled_with_random: bool, pub stick_initialized: bool,
}
Stores the status of a Storage device.

Fields

unencrypted_volume_read_only: bool

Indicates whether the unencrypted volume is read-only.

unencrypted_volume_active: bool

Indicates whether the unencrypted volume is active.

encrypted_volume_read_only: bool

Indicates whether the encrypted volume is read-only.

encrypted_volume_active: bool

Indicates whether the encrypted volume is active.

hidden_volume_read_only: bool

Indicates whether the hidden volume is read-only.

hidden_volume_active: bool

Indicates whether the hidden volume is active.

firmware_version_major: u8

The major firmware version, e. g. 0 in v0.40.

firmware_version_minor: u8

The minor firmware version, e. g. 40 in v0.40.

firmware_locked: bool

Indicates whether the firmware is locked.

serial_number_sd_card: u32

The serial number of the SD card in the Storage stick.

serial_number_smart_card: u32

The serial number of the smart card in the Storage stick.

user_retry_count: u8

The number of remaining login attempts for the user PIN.

admin_retry_count: u8

The number of remaining login attempts for the admin PIN.

new_sd_card_found: bool

Indicates whether a new SD card was found.

filled_with_random: bool

Indicates whether the SD card is filled with random characters.

stick_initialized: bool

Indicates whether the stick has been initialized by generating the AES keys.